@@ -196,6 +196,7 @@ save_plot_list = ["class plot_class():\n",
 "            ax[count].set_ylim(data['y_lim'])\n",
 "            ax[count].set_xscale(scale[data['xscale']])\n",
 "            ax[count].set_yscale(scale[data['yscale']])\n",
+"            ax[count].tick_params(labelsize=data['axis_text']['size']-3)\n",
 "            if data['xticks'] == 0:\n",
 "                ax[count].set_xticks([], [])\n",
 "            if data['yticks'] == 0:\n",
@@ -501,6 +502,7 @@ save_plot2_list = ["class plot_class():\n",
 "                    self.axes[i][j].set_ylim(y_lim)\n",
 "                    self.axes[i][j].set_xscale(scale[x_scale])\n",
 "                    self.axes[i][j].set_yscale(scale[y_scale])\n",
+"                    self.axes[i][j].tick_params(labelsize=data['axis_text']['size']-3)\n",
 "                    if data['xticks'] == 0:\n",
 "                        self.axes[i][j].set_xticks([], [])\n",
 "                    if data['yticks'] == 0:\n",
